#!env perl
use MyCPAN::App::BackPAN::Indexer;

MyCPAN::App::BackPAN::Indexer->activate( @ARGV );

exit( 0 );
